﻿// ------------------------------
// Cricket Sidebar Gadget
// by Matt Sharpe
//
// Code based on MSDN Ticker by LiveGadgets.net
// Downloads Live Scores RSS from Cricinfo.com

var refreshRate = 60; //number of seconds between RSS reloads
var feedItems; //array of RSS feed items
var feedTimer; //timeout object for reading RSS
var item; //currently selected item (for flyout)
var scrollTimer; //interval object for display scroller
var scrollOuterEl; //outer scroll element
var ballEl; //ball element
var scoreEl; //inner scroll element
var sliderCurrent; //left position (in pixels) of the scoreEl within scrollOuterEl
var flyoutDocument; //document object of the flyout window
var feedUrl = 'http://www.cricinfo.com/rss/livescores.xml';
var itemIndex = -1;
var pause = new Boolean(false);

// called when the gadget loads
function pageLoad() {
	window.detachEvent("onload", pageLoad);
	window.attachEvent("onunload", pageUnload);
	
	var el, gadgetEl;

	feedItems = []; //setup an empty array for the RSS feed items

	gadgetEl = document.getElementById("gadget"); //get the container

	ballEl = document.createElement("div");
	ballEl.innerHTML=" ";
	ballEl.className = "ballDiv";
	ballEl.attachEvent("onmouseover", setHoverBall);
	ballEl.attachEvent("onmouseout", clearHoverBall);
	ballEl.attachEvent("onmouseup", togglePause);
	gadgetEl.appendChild(ballEl);

	//dynamically create our content
	scrollOuterEl = document.createElement("div");
	scrollOuterEl.className = "outerDiv";
	//scrollOuterEl.attachEvent("onmouseover", setHover);
	//scrollOuterEl.attachEvent("onmouseout", clearHover);
	gadgetEl.appendChild(scrollOuterEl);

	document.attachEvent("onmouseover", setHover);
	document.attachEvent("onmouseout", clearHover);	

	scoreEl = document.createElement("div");
	scoreEl.className = "slider";
	scoreEl.innerHTML = 'Loading...';
	scrollOuterEl.appendChild(scoreEl);

	if (feedTimer) {
		clearTimeout(feedTimer);
		feedTimer = setTimeout(getFeed, 1000*refreshRate); //reload again in an X seconds
	}

	System.Gadget.background = "background.png";
	document.body.style.width = "130px";
	document.body.style.height = "72px";

	getFeed(); //start loading the RSS feed
	clearHover(); //setup the scroll timer

	el = gadgetEl = null;
}

// called after the RSS file is loaded
function onXmlReturnHandler(xdoc) {
	var n, node, nodes, item;
	feedItems = []; //clear the old array
	try {
		nodes = xdoc.selectNodes("/rss/channel/item");
		for (n=0; n < nodes.length; n++){
			node = nodes[n];
			item = {};
			item.title = node.selectSingleNode('title').text;
			item.link = node.selectSingleNode('link').text;
			item.description = node.selectSingleNode('description').text;
			feedItems.push(item);
		}
	} catch(ex) {}
	nodes = item = xdoc = null;
	//setup timer to load again
	feedTimer = setTimeout(getFeed, 1000*refreshRate); //reload again in an X hours
}

// called once every minute to load a new RSS feed
function getFeed() {
	//shut down feed timer (if running)
	if (feedTimer) {
		clearTimeout(feedTimer);
		feedTimer=null;
	}
	var xdoc = new ActiveXObject("Microsoft.XMLDOM");
	xdoc.onreadystatechange = function () {
		if ( xdoc.readyState == 4 ) {
			onXmlReturnHandler(xdoc);
		}
	};
	xdoc.load(feedUrl);
}


function scrollDisplay() {
	var span;
	if (pause == false) {
		itemIndex++;
		if (itemIndex >= feedItems.length) {
			itemIndex=0;
		}
	}
	//build news feed DIV
	scoreEl.innerHTML = "";
	span = document.createElement("span");
	if (feedItems.length > 0) {
		span.innerHTML = hesc(feedItems[itemIndex].title);
	} else {
		span.innerHTML = "No scores available";
	}
	scoreEl.appendChild(span);


}

// called when the user hovers over the scroll area
// setup the scroll timer in "slow" mode
function setHover() {
	setSpeed(0);
}

function clearHover() {
	setSpeed(5000);
}

function setHoverBall() {
	if (pause == true) {
		ballEl.style.background='url(ball-pause-h.png)';
	} else {
		ballEl.style.background='url(ball-normal-h.png)';
	}
}

function clearHoverBall() {
	if (pause == true) {
		ballEl.style.background='url(ball-pause.png)';
	} else {
		ballEl.style.background='url(ball-normal.png)';
	}
}

function togglePause() {
	if (pause == true) {
		pause = false;
		ballEl.style.background='url(ball-normal-h.png)';
	} else {
		pause = true;
		ballEl.style.background='url(ball-pause-h.png)';
	}
}

function setSpeed(speed) {
	if (scrollTimer) {
		clearInterval(scrollTimer);
	}
	if (speed == 0) {
		scrollTimer = null;
	} else {
		scrollTimer = setInterval(scrollDisplay, speed);
	}
}

// called when the gadget unloads
function pageUnload() {
    window.detachEvent("onunload", pageUnload);

	//shut down timers (if running)
	if (feedTimer) {
		clearTimeout(feedTimer);
		feedTimer=null;
	}
	if (scrollTimer) {
		clearInterval(scrollTimer);
		scrollTimer=null;
	}

	//unhook mouse over/out events
	document.detachEvent("onmouseover", setHover);
	document.detachEvent("onmouseout", clearHover);
	ballEl.detachEvent("onmouseover", setHoverBall);
	ballEl.detachEvent("onmouseout", clearHoverBall);
	ballEl.detachEvent("onmouseup", togglePause);

	flyoutDocument = feedItems = item = scoreEl = scrollOuterEl = null;
}



// ------------------------------
// global functions

//escape an HTML string
function hesc(p_str) {
    var newstr = p_str.replace(/&/g,"&amp;").replace(/</g, "&lt;").replace(/>/g,"&gt;").replace(/\"/g,"&quot;").replace(" v ","<br>");
    return newstr;
}

// ------------------------------
// this gets everything started after the DOM is created
window.attachEvent("onload", pageLoad);

